%% Structural VAR
clear
clc

% Load data
load_data
load_DM2_data

clc
%close all

Y = [l_gdp, l_gdp_defl, l_pcomm, l_dm2, l_mb, l_rucm2];

Y = Y(1:end,:); %1:end = 1967:Q1 - 2015:Q4 // 1:164 = 1967:Q1 - 2007:Q4 // 1:114 = 1967:Q1 - 1995:Q2

%% SET LAG LENGTH
vlag = 5;

%% ESTIMATE WITH CONSTANT BUT NO TIME TREND
iscon = 1;

%% NOW ESTIMATE
[Bcomp, cvec, Bpl_ev, VC_eps, Residmat] = ...
									estim(Y, vlag, iscon);
									
%% SET NUMBER OF IRF PERIODS (adds first period so 15 implies 16 periods will be computed)
IRhoriz = 16;

%% SET OPTIONS FOR CONFIDENCE BANDS (MONTE CARLO INTEGRATION OF CONFIDENCE BANDS, SEE KOOP AND KOROBILIS, 2010)
NMC    = 10000;							% NUMBER OF DRAWS FROM THE POSTERIOR DISTRIBUTION
CIperc = [0.05, 0.95];					% CHOOSE WHICH PERCENTILES TO PLOT
[IRpoint, IRup_2, IRup_1, IRlo_1, IRlo_2, IRmed] = confid_int(Bcomp,VC_eps,cvec,IRhoriz,NMC,Y,CIperc);

irflength = IRhoriz+1;
t = 0:IRhoriz;
figure(1)
subplot(6,3,3)
hold on
jbfill(t,-IRup_2(:,1,4)',-IRlo_2(:,1,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,1,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('GDP','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-1.2 0.8]);set(gca,'YTick',[-1.2:0.4:0.8],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

subplot(6,3,6)
hold on
jbfill(t,-IRup_2(:,2,4)',-IRlo_2(:,2,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,2,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('GDP Deflator','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-1.25 0.5]);set(gca,'YTick',[-1.25:0.25:0.5],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

subplot(6,3,9)
hold on
jbfill(t,-IRup_2(:,3,4)',-IRlo_2(:,3,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,3,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('Commodity Prices','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-6.0 1.5]);set(gca,'YTick',[-6.0:1.5:1.5],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

subplot(6,3,12)
hold on
jbfill(t,-IRup_2(:,4,4)',-IRlo_2(:,4,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,4,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('Divisia M2','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-2.0 0.0]);set(gca,'YTick',[-2.0:0.5:0.0],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

subplot(6,3,15)
hold on
jbfill(t,-IRup_2(:,5,4)',-IRlo_2(:,5,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,5,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('Monetary Base','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-3 2]);set(gca,'YTick',[-3:1.0:2],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

subplot(6,3,18)
hold on
jbfill(t,-IRup_2(:,6,4)',-IRlo_2(:,6,4)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,-IRpoint(:,6,4),'-r','LineWidth',0.5);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 0.5); 
title('User Cost DM2','FontSize',6);xlim([t(1) t(end)]);set(gca,'XTick',t(1:2:end),'FontSize',6);
ylim([-6.0 6.0]);set(gca,'YTick',[-6.0:2.0:6.0],'FontSize',6);
box on; grid on;
set(gca, 'Layer', 'top');

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'portrait');
set(gcf, 'PaperPosition', [-0.9 -1.0 9.5 12.0]);
set(gcf, 'PaperSize', [8.0 10.25]);
print(['MSS16-420Fig10.pdf'],'-dpdf')