function [residual, g1, g2] = kksvMPshocks_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 17, 1);

%
% Model equations
%

lhs =y(1);
rhs =y(1)*params(2)/(1+params(2))+y(1)*1/(1+params(2))-(1-params(2))/(1+params(2))*(y(3)-y(2));
residual(1)= lhs-rhs;
lhs =y(4);
rhs =y(1)*(1+(1-params(2))*params(11))/((1-params(2))*(1+params(11)))-y(1)*params(2)/((1-params(2))*(1+params(11)))-y(3)*params(4);
residual(2)= lhs-rhs;
lhs =y(2);
rhs =y(2)+params(12)*(y(1)*1/(1-params(2))-y(1)*params(2)/(1-params(2)));
residual(3)= lhs-rhs;
lhs =y(5);
rhs =y(4)+y(3)*params(5)*((1+params(11))*params(4)-1/(params(9)-1));
residual(4)= lhs-rhs;
lhs =y(6);
rhs =y(4)+y(3)*params(5)*((1+params(11))*params(4)-(params(7)-params(8)*(1-params(7)))/(params(9)-params(10)));
residual(5)= lhs-rhs;
lhs =y(7);
rhs =y(2);
residual(6)= lhs-rhs;
lhs =y(8);
rhs =y(2);
residual(7)= lhs-rhs;
lhs =y(9);
rhs =y(2);
residual(8)= lhs-rhs;
lhs =y(10);
rhs =y(2)+y(10);
residual(9)= lhs-rhs;
lhs =y(11);
rhs =y(7)+y(11);
residual(10)= lhs-rhs;
lhs =y(12);
rhs =y(8)+y(12);
residual(11)= lhs-rhs;
lhs =y(13);
rhs =y(9)+y(13);
residual(12)= lhs-rhs;
lhs =y(14);
rhs =y(10);
residual(13)= lhs-rhs;
lhs =y(15);
rhs =y(14);
residual(14)= lhs-rhs;
lhs =y(16);
rhs =y(1);
residual(15)= lhs-rhs;
lhs =y(17);
rhs =y(16);
residual(16)= lhs-rhs;
lhs =y(3)*params(15)+y(7)*(1-params(15));
rhs =params(15)*(y(3)*params(17)+(1-params(17))*(y(2)*params(18)+params(19)*y(1)*(1-params(16)))+x(1))+(1-params(15))*((1-params(17))*(y(2)*params(18)+params(19)*y(1)*(1-params(16)))+y(7)*params(17)-x(1));
residual(17)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(17, 17);

  %
  % Jacobian matrix
  %

  g1(1,1)=1-(params(2)/(1+params(2))+1/(1+params(2)));
  g1(1,2)=(-((1-params(2))/(1+params(2))));
  g1(1,3)=(1-params(2))/(1+params(2));
  g1(2,1)=(-((1+(1-params(2))*params(11))/((1-params(2))*(1+params(11)))-params(2)/((1-params(2))*(1+params(11)))));
  g1(2,3)=params(4);
  g1(2,4)=1;
  g1(3,1)=(-(params(12)*(1/(1-params(2))-params(2)/(1-params(2)))));
  g1(4,3)=(-(params(5)*((1+params(11))*params(4)-1/(params(9)-1))));
  g1(4,4)=(-1);
  g1(4,5)=1;
  g1(5,3)=(-(params(5)*((1+params(11))*params(4)-(params(7)-params(8)*(1-params(7)))/(params(9)-params(10)))));
  g1(5,4)=(-1);
  g1(5,6)=1;
  g1(6,2)=(-1);
  g1(6,7)=1;
  g1(7,2)=(-1);
  g1(7,8)=1;
  g1(8,2)=(-1);
  g1(8,9)=1;
  g1(9,2)=(-1);
  g1(10,7)=(-1);
  g1(11,8)=(-1);
  g1(12,9)=(-1);
  g1(13,10)=(-1);
  g1(13,14)=1;
  g1(14,14)=(-1);
  g1(14,15)=1;
  g1(15,1)=(-1);
  g1(15,16)=1;
  g1(16,16)=(-1);
  g1(16,17)=1;
  g1(17,1)=(-(params(15)*(1-params(17))*params(19)*(1-params(16))+(1-params(15))*(1-params(17))*params(19)*(1-params(16))));
  g1(17,2)=(-(params(15)*(1-params(17))*params(18)+(1-params(15))*(1-params(17))*params(18)));
  g1(17,3)=params(15)-params(15)*params(17);
  g1(17,7)=1-params(15)-(1-params(15))*params(17);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],17,289);
end
end
