%% THIS SCRIPT MINIMIZES THE DISTANCE BETWEEN THE IRFS 
%% UNDER A TAYLOR RULE AND A MONEY GROWTH RULE IN THE
%% KKSV DSGE MODEL

clear
clc

%% SETUP DYNARE

Rrule	= 1;
Grule   = 0;
rho		= 0.79;
rhoinfl	= 2.15;
rhoy	= 0.93;
sigmamp	= 0.0025;
save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
dynare kksvMPshocksDeterminacy nolog noclearall
dynare kksvMPshocks nolog noclearall

clear
clc
close all

%% DECLARE OPTIONS
graph = 1; %% GRAPHS THE RESULTING IRFS

%% FIRST COMPUTE THE TAYLOR RULE IRF TO FIND THE TARGETS 
%% RruleTR = 1 --> Interest rate instrument / 0 --> Money growth instrument
%% GruleTR = 1 --> Output growth / GruleTR = 0 --> Output level
RruleTR		= 1;
GruleTR		= 0;		%1;		%0;		%0;
rhoTR		= 0.0;		%0.94; 	%0.79;	%0
rhoinflTR	= 1.5;		%2.20; 	%2.15;	%1.5 
rhoyTR		= 0.125;	%2.69; 	%0.93;	%0.125
sigmampTR	= 0.0025;

Rrule		= RruleTR;
Grule		= GruleTR;
rho 		= rhoTR;
rhoinfl 	= rhoinflTR;
rhoy 		= rhoyTR;
sigmamp 	= sigmampTR;
save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
kksvMPshocks
TR_IRF 	= [10*lagexpy_emp, 10*lagexpp_emp, 10*nm_emp, nm_b_emp, 10*r_emp];

%% SPECIFY STARTING VALUES
sigmamp =  0.0263;
rho 	=  0.0000;
rhoinfl = -0.3578;
rhoy   	= -0.7497;

big_theta_init = [
((2 - .00001)/(sigmamp - .00001)) - 1;	  
((0.99 - (-.99))/(rho - (-.99))) - 1;			  
((1 - (-10))/(rhoinfl - (-10))) - 1;		  
((1 - (-10))/(rhoy - (-10))) - 1];		  
big_theta_init = 5*log(big_theta_init);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% START THE MINIMIZER
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
options=optimset('Display','notify','MaxIter',10000,'MaxFunEvals',100000,'TolX',1e-8,'TolFun',1e-8);
%%
[big_theta_star,fval]  = fminsearch(@(big_theta) mp_irf_resid(big_theta,TR_IRF,Grule),big_theta_init,options);
%%
sigmampstar = .00001 + (2 - .00001)/(1+exp(.2*big_theta_star(1,1)))
rhostar 	= (-.99) + (0.99 - (-.99))/(1+exp(.2*big_theta_star(2,1)))
rhoinflstar = (-10) + (1 - (-10))/(1+exp(.2*big_theta_star(3,1)))
rhoystar   	= (-10) + (1 - (-10))/(1+exp(.2*big_theta_star(4,1)))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if graph == 1;
	%%
	Rrule	= 1;
	rho 	= rhoTR;
	rhoinfl = rhoinflTR;
	rhoy 	= rhoyTR;
	sigmamp = sigmampTR;
	save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
	kksvMPshocks
	irf_storage(:,:,1) = [lagexpy_emp, lagexpp_emp, nm_emp, nm_b_emp, 4*r_emp];
	%%
	Rrule	= 0;
	rho 	= rhostar;
	rhoinfl = rhoinflstar;
	rhoy 	= rhoystar;
	sigmamp = sigmampstar;
	save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
	kksvMPshocks
	irf_storage(:,:,2) = [lagexpy_emp, lagexpp_emp, nm_emp, nm_b_emp, 4*r_emp];
	%%
	[nperiods,nvariables] = size(irf_storage(:,:,1));
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	%% variable names
	s.a = 'Output';
	s.b = 'Price Level';
	s.c = 'Monetary Aggregate';
	s.d = 'Monetary Base';
	s.e = 'Short-Term Rate';
	%%
	sn = fieldnames(s);
	sl = length(sn);
	%%
	vs = [1;2;3;4;5];
	vl = length(vs);
	%%
	xs = 0:1:nperiods;
	%%
	figure;
	for ss = 1:1:vl;
			ss = vs(ss);
			subplot(3,2,ss);
			%
			plot(xs,zeros(nperiods+1,1),'-k'); hold on;
			h1 = plot(irf_storage(:,ss,1),'--ob','LineWidth',1.5); hold on;
			h2 = plot(irf_storage(:,ss,2),'-r','LineWidth',1.5); hold on;
			%%
			y_max = max(max(squeeze(irf_storage(:,ss,:))));
			y_max = y_max + .25*abs(y_max);
			y_min = min(min(squeeze(irf_storage(:,ss,:))));
			y_min = y_min - .25*abs(y_min);
			%%
			%% THE FOLLOWING BOXES IN THE PLOTS (%% COMMENT OUT IF UNDERSIRED)
			plot([1, 1], [y_min, y_max], 'k');
			plot([nperiods, nperiods], [y_min, y_max], 'k');
			plot([1, nperiods], [y_min, y_min], 'k');
			plot([1, nperiods], [y_max, y_max], 'k');
			%%
			xlim([1 nperiods]);
			ylim([y_min y_max]);
			%%
			title1 = s.(sn{ss});
			fontsizetitle = '\fontsize{15}\bf{';
			title2 = [fontsizetitle title1 '}'];
			title(title2)
			hold off;
		%%
			if ss == 5;
				lh = legend([h1 h2],{'Rate Rule','Money Rule'},'Location','NorthEast');
				font_size = 10;
				set(lh,'Interpreter','latex','Orientation','horizontal',...
				'Position',[0.317708333333333 0.00766283524904202 0.402083333333333 0.043103448275862]);
			end;
		%%
	end;		
	%
end; %% if graph