%% THIS SCRIPT PLOTS THE MATCHED IRFS FROM THE match_mp_irf SCRIPT
clear
clc

%% SETUP DYNARE

Rrule	= 1;
Grule   = 0;
rho		= 0.79;
rhoinfl	= 2.15;
rhoy	= 0.93;
sigmamp	= 0.0025;
save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
dynare kksvMPshocks nolog noclearall

clear
clc
close all

%% TR PARAMETERS
GruleTR		= [1.0000, 0.0000, 0.0000];	% GruleTR = 1 if output growth appears in the rule and GruleTR = 0 if output (gap) appears in the rule
rhoTR		= [0.9400, 0.7900, 0.0000];
rhoinflTR	= [2.2000, 2.1500, 1.5000];
rhoyTR		= [2.6900, 0.9300, 0.1250];
sigmampTR	= [0.0025, 0.0025, 0.0025];

%% CORRESPONDING MG PARAMETERS
rhoMG		= [-0.0016,  0.0502,  -0.3230];
rhoinflMG	= [ 0.6510, -1.1801, -10.0000];
rhoyMG		= [ 0.5399, -0.7085,  -4.5092];
sigmampMG	= [ 0.0067,  0.0075,   0.0111];

nmodels = size(rhoTR,2);

for mm = 1:1:nmodels;
	Rrule	= 1;
	Grule	= GruleTR(mm);
	rho		= rhoTR(mm);
	rhoinfl	= rhoinflTR(mm);
	rhoy	= rhoyTR(mm);
	sigmamp	= sigmampTR(mm);
	save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
	kksvMPshocks
	irf_storageTR(:,:,mm) = 100*[lagexpy_emp, lagexpp_emp, nm_emp, nm_b_emp, 4*r_emp];
	%% GET MG IRFS
	Rrule	= 0;
	Grule	= GruleTR(mm);
	rho		= rhoMG(mm);
	rhoinfl	= rhoinflMG(mm);
	rhoy	= rhoyMG(mm);
	sigmamp	= sigmampMG(mm);
	save parameterfile Rrule Grule rho rhoinfl rhoy sigmamp
	kksvMPshocks
	irf_storageMG(:,:,mm) = 100*[lagexpy_emp, lagexpp_emp, nm_emp, nm_b_emp, 4*r_emp];
end;

[nperiods,nvariables] = size(irf_storageTR(:,:,1));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% variable names
s.a = 'Output';
s.b = 'Price Level';
s.c = 'Monetary Aggregate';
s.d = 'Monetary Base';
s.e = 'Short-Term Rate';
sn = fieldnames(s);
sl = length(sn);
%%
m.a = 'Estimated Rule';
m.b = 'Clarida et al. (2000) Rule';
m.c	= 'Taylor (1993) Rule';
mn = fieldnames(m);
%%
xs = 0:1:nperiods;
%%
ymin = [-1.0, -2.5, -2.5, -6.0, -0.1];
ymax = [0.2,   0.5,  0.5,  1.0,  0.15];
yspace = 0.2;
mm = 1;
plot_pos = 1;
figure(1);

for ss = 1:1:sl;
	subplot(6,3,plot_pos);
	%
	plot(xs,zeros(nperiods+1,1),'-k'); hold on;
	h1 = plot(irf_storageTR(:,ss,mm),'--ob','LineWidth',1.5); hold on;
	h2 = plot(irf_storageMG(:,ss,mm),'-r','LineWidth',1.5); hold on;
	%%
	y_max = max(max(squeeze(irf_storageTR(:,ss,mm))));
	y_max = y_max + yspace*abs(y_max);
	y_min = min(min(squeeze(irf_storageTR(:,ss,mm))));
	y_min = y_min - yspace*abs(y_min);
	%%
	if  ss < sl;
		xlim([1 nperiods]);
		ylim([y_min max([y_max,0])]);
	else
		xlim([1 nperiods]);
		ylim([y_min y_max]);
	end;
	%%
	title1 = s.(sn{ss});
	fontsizetitle = '\fontsize{8}{';
	title2 = [fontsizetitle title1 '}'];
	title(title2)
	
	set(gca,'XTick',xs(1:2:end),'FontSize',6);
		
	box on; grid on;
	set(gca, 'Layer', 'top');
		
	hold off;
	plot_pos = plot_pos + 3;
end;
%%
mm = 2;
plot_pos = 2;
for ss = 1:1:sl;
	subplot(6,3,plot_pos);
	%
	plot(xs,zeros(nperiods+1,1),'-k'); hold on;
	h1 = plot(irf_storageTR(:,ss,mm),'--ob','LineWidth',1.5); hold on;
	h2 = plot(irf_storageMG(:,ss,mm),'-r','LineWidth',1.5); hold on;
	%%
	y_max = max(max(squeeze(irf_storageTR(:,ss,mm))));
	y_max = y_max + yspace*abs(y_max);
	y_min = min(min(squeeze(irf_storageTR(:,ss,mm))));
	y_min = y_min - yspace*abs(y_min);
	%%
	if  ss < sl;
		xlim([1 nperiods]);
		ylim([y_min max([y_max,0])]);
	else
		xlim([1 nperiods]);
		ylim([y_min y_max]);
	end;
	%%
	title1 = s.(sn{ss});
	fontsizetitle = '\fontsize{8}{';
	title2 = [fontsizetitle title1 '}'];
	title(title2)
	
	set(gca,'XTick',xs(1:2:end),'FontSize',6);
		
	box on; grid on;
	set(gca, 'Layer', 'top');
		
	hold off;
	plot_pos = plot_pos + 3;
end;
%%
mm = 3;
plot_pos = 3;
for ss = 1:1:sl;
	subplot(6,3,plot_pos);
	%
	plot(xs,zeros(nperiods+1,1),'-k'); hold on;
	h1 = plot(irf_storageTR(:,ss,mm),'--ob','LineWidth',1.5); hold on;
	h2 = plot(irf_storageMG(:,ss,mm),'-r','LineWidth',1.5); hold on;
	%%
	y_max = max(max(squeeze(irf_storageTR(:,ss,mm))));
	y_max = y_max + yspace*abs(y_max);
	y_min = min(min(squeeze(irf_storageTR(:,ss,mm))));
	y_min = y_min - yspace*abs(y_min);
	%%
	if  ss < sl;
		xlim([1 nperiods]);
		ylim([y_min max([y_max,0])]);
	else
		xlim([1 nperiods]);
		ylim([y_min y_max]);
	end;
	%%
	title1 = s.(sn{ss});
	fontsizetitle = '\fontsize{8}{';
	title2 = [fontsizetitle title1 '}'];
	title(title2)
	
	set(gca,'XTick',xs(1:2:end),'FontSize',6);

	if ss == sl
		hleglines = [h1(1) h2(1)];
		legend = legend(hleglines, 'Rate Rule','Money Rule');
		set(legend,'Location','NorthEast','FontSize',10);
	end
	
	box on; grid on;
	set(gca, 'Layer', 'top');
		
	hold off;
	plot_pos = plot_pos + 3;
end;
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'portrait');
set(gcf, 'PaperPosition', [-0.7 -2.75 9.5 12.0]);
set(gcf, 'PaperSize', [8.75 8.5]);
print(['MSS16-420Fig1.pdf'],'-dpdf')