%% Structural VAR
clear
clc

% Load data
load_data

clc
close all

Y = [l_gdp, l_gdp_defl, l_pcomm, l_dm4, l_mb, l_rucm4];

Y = Y(1:end,:); %1:end = 1967:Q1 - 2015:Q4 // 1:164 = 1967:Q1 - 2007:Q4 // 1:114 = 1967:Q1 - 1995:Q2
[Tbig,Nbig] = size(Y);

%% SET LAG LENGTH
vlag = 5;

%% ESTIMATE WITH CONSTANT BUT NO TIME TREND
iscon = 1;
istr  = 0;

%% ESTIMATE
[Bcomp, cvec, dvec, Bpl_ev, VC_eps, Residmat] = ...
									estim(Y, vlag, iscon, istr);
									
%% MAP REDUCED FORM SHOCKS INTO STRUCTURAL SHOCKS
%% IF e_t (Nbig x 1) represents the reduced form VAR residual and eps_t denote the structural VAR residual  at time t,
%% then with the recursive identification scheme imposed by the Choleski decomposition, we have that at each time t
%% e_t = VC_epschol*eps_t. So we can recover eps_t from e_t using the equation eps_t = inv(VC_epschol)*e_t. 
VC_epschol = chol(VC_eps)';
inv_VC_epschol = inv(VC_epschol);
struct_shocks = Residmat*inv_VC_epschol';

%% SUM MP SHOCKS BEGINNING IN 2008:Q4
MPshocks = zeros(size(struct_shocks(:,4),1),1);
MPshocks(168-vlag:end,1) = struct_shocks(168-vlag:end,4);
cumMPshocks = cumsum(MPshocks); 

t = 1967.0:0.25:2015.75;

%% CALCULATE QE DATES
% QE 1 = 2008:Q4 t(168)
% QE 2 = 2010:Q4 t(176)
% QE 3 = 2012:Q3 t(183)
% TT   = 2013:Q2 t(186)
yQE = -5:1:10;

plot_extra = 1;
plot_cut   = 8;
%t = -plot_extra:1:size(struct_shocks(168-vlag:end,4),1)-1-plot_cut;

figure(1);
plot(t(167:188),cumMPshocks(168-vlag-plot_extra:end-plot_cut,1),'-k','LineWidth',1.5);
hold on;
plot(t(167:188),zeros(size(cumMPshocks(168-vlag-plot_extra:end-plot_cut,1),1),1),'-k','LineWidth',0.5);
title('Cumulative Monetary Policy Shocks','FontSize',18);
plot(ones(length(yQE),1)*t(168),yQE,'-k','LineWidth',0.5);
plot(ones(length(yQE),1)*t(176),yQE,'-k','LineWidth',0.5);
plot(ones(length(yQE),1)*t(183),yQE,'-k','LineWidth',0.5);
plot(ones(length(yQE),1)*t(186),yQE,'-k','LineWidth',0.5);
text(t(168)+0.02,2.75,'QE 1','FontSize',12,'FontWeight','bold');
text(t(176)+0.02,2.75,'QE 2','FontSize',12,'FontWeight','bold');
text(t(183)+0.02,2.75,'QE 3','FontSize',12,'FontWeight','bold');
text(t(186)+0.02,2.75,{'Taper','Tantrum'},'FontSize',12,'FontWeight','bold');
%ylabel('Log-scale','FontSize',8);
set(gca,'XTick',t(167:end),'FontSize',12);
set(gca,'XTickLabel',{'','2008',...
					  '','','','2009',...
					  '','','','2010',...
					  '','','','2011',...
					  '','','','2012',...
					  '','','','2013'},'FontSize',12);
ylim([-1.5 3.0]);set(gca,'YTick',[-1.5:0.5:3.0],'FontSize',12);
xlim([t(167) t(188)]);
ylim([-1.5 3]);
box on; 
%grid on;
set(gca, 'Layer', 'top');
hold off;

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'landscape');
set(gcf, 'PaperPosition', [-0.7 -0.45 11.0 6.9]);
set(gcf, 'PaperSize', [9.75 6.25]);
print(['MSS16-420Fig3.pdf'],'-dpdf')