%% Structural VAR
clear
clc

% Load data
load_data
load_gd_data

clc
%close all

Y = [l_gdp, l_gdp_defl, l_pcomm, l_dm4, l_mb, l_rucm4];

Y = Y(1:end,:); %1:end = 1967:Q1 - 2015:Q4 // 1:164 = 1967:Q1 - 2007:Q4 // 1:114 = 1967:Q1 - 1995:Q2
[Tbig,Nbig] = size(Y);

%% SET LAG LENGTH
vlag = 5;

%% ESTIMATE WITH CONSTANT BUT NO TIME TREND
iscon = 1;

%% NOW ESTIMATE
[Bcomp, cvec, Bpl_ev, VC_eps, Residmat] = ...
									estim(Y, vlag, iscon);
									
%% COMPUTE DESIRED PATH OF BROAD MONEY
m_path = l_dm4;
m_path(163:end) = l_hm2(34:67)+l_dm4(163)-l_hm2(34);

%% COMPUTE COUNTERFACTUAL MP SHOCKS WHICH DELIVER THAT PATH
[Residmatcf] = match_m_path(Bcomp, VC_eps, Y, cvec, Residmat, m_path);

%% COMPUTE COUNTERFACTUAL PATHS OF OUTPUT AND INFLATION
[path] = get_path(Bcomp, VC_eps, Y, cvec, Residmatcf);

%% NORMALIZE OUTPUT IN GREAT DEPRESSION AND DEFINE INFLATION FOR PLOTTING
l_gdp_gd = l_gnp - l_gnp(34) + l_gdp(163);
l_m2_gd  = l_hm2 - l_hm2(34) + l_dm4(163);
infl     = [zeros(4,1); Y(5:end,2) - Y(1:end-4,2)];
inflcf   = [zeros(4,1); path(5:end,2) - path(1:end-4,2)];
infl_gd  = [zeros(4,1); l_gnp_defl(5:end) - l_gnp_defl(1:end-4)];

GDCFpeaktotrough = min(path(164:end,1))-path(164,1)
DATApeaktotrough = min(l_gdp(164:end))-l_gdp(164,1)
GDpeaktotrough	 = min(l_gnp(35:end)) - l_gnp(35)

plot_extra = 4;
t = -plot_extra:1:size(path(164:end,1),1)-1;

figure(1);
subplot(3,2,2);
plot(t,Y(164-plot_extra:end,1)/100,'-b');
hold on;
plot(t,path(164-plot_extra:end,1)/100,'--r');
title('GDP')
ylabel('Log-scale','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([9.4 9.8]);set(gca,'YTick',[9.4:0.1:9.8],'FontSize',6);
xlim([t(1) t(end)]);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;

subplot(3,2,4);
plot(t,infl(164-plot_extra:end),'-b');
hold on;
plot(t,inflcf(164-plot_extra:end),'--r');
title('GDP Deflator')
ylabel('Y/Y % Chg','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([-6.0 4.0]);set(gca,'YTick',[-6.0:2.0:4.0],'FontSize',6);
xlim([t(1) t(end)]);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;

subplot(3,2,6);
plot(t,Y(164-plot_extra:end,4)/100,'-b');
hold on;
plot(t,path(164-plot_extra:end,4)/100,'--r');
title('Divisia M4')
ylabel('Log-scale','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([6.4 7.4]);set(gca,'YTick',[6.4:0.2:7.4],'FontSize',6);
xlim([t(1) t(end)]);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'portrait');
set(gcf, 'PaperPosition', [-0.7 -1.0 9.5 12.0]);
set(gcf, 'PaperSize', [8.5 10.25]);
print(['MSS16-420Fig7.pdf'],'-dpdf')