%% Structural VAR
clear
clc

% Load data
load_data

clc
close all

Y = [l_gdp, l_gdp_defl, l_pcomm, l_dm4, l_mb, l_rucm4];

Y = Y(1:end,:); %1:end = 1967:Q1 - 2015:Q4 // 1:164 = 1967:Q1 - 2007:Q4 // 1:114 = 1967:Q1 - 1995:Q2
[Tbig,Nbig] = size(Y);

%% SET LAG LENGTH
vlag = 5;

%% ESTIMATE WITH CONSTANT BUT NO TIME TREND
iscon = 1;

%% NOW ESTIMATE
[Bcomp, cvec, Bpl_ev, VC_eps, Residmat] = ...
									estim(Y, vlag, iscon);
									
%% MAP REDUCED FORM SHOCKS INTO STRUCTURAL SHOCKS
%% IF e_t (Nbig x 1) represents the reduced form VAR residual and eps_t denote the structural VAR residual  at time t,
%% then with the recursive identification scheme imposed by the Choleski decomposition, we have that at each time t
%% e_t = VC_epschol*eps_t. So we can recover eps_t from e_t using the equation eps_t = inv(VC_epschol)*e_t. 
VC_epschol = chol(VC_eps)';
inv_VC_epschol = inv(VC_epschol);
struct_shocks = Residmat*inv_VC_epschol';

%% TURN OFF MP SHOCKS BEGINNING IN 2008:Q4 
struct_shocks(168-vlag:end,4) = zeros(size(struct_shocks(168-vlag:end,4),1),1);

%% MAP STRUCTURAL SHOCKS BACK INTO REDUCED FORM SHOCKS
Residmatcf = struct_shocks*VC_epschol';

[path] = get_path(Bcomp, VC_eps, Y, cvec, Residmatcf);

%% CALCULATE INFLATION AND COUNTERFACTUAL EFFECTS
infl   = [zeros(4,1); Y(5:end,2) - Y(1:end-4,2)];
inflcf = [zeros(4,1); path(5:end,2) - path(1:end-4,2)];
cfGDP = path(end,1)-Y(end,1)
cfP   = path(end,2)-Y(end,2)

plot_extra = 8;
t = -plot_extra:1:size(struct_shocks(168-vlag:end,4),1)-1;

figure(1);
subplot(3,2,1);
h1=plot(t,Y(168-plot_extra:end,1)/100,'-b');
hold on;
h2=plot(t,path(168-plot_extra:end,1)/100,'--r');
title('GDP')
ylabel('Log-scale','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([9.5 9.8]);set(gca,'YTick',[9.5:0.1:9.8],'FontSize',6);
xlim([t(1) t(end)]);
clear legend;
hleglines = [h1(1) h2(1)];
legend = legend(hleglines, 'Data','Counterfactual');
set(legend,'Location','NorthWest','FontSize',10);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;

subplot(3,2,3);
plot(t,infl(168-plot_extra:end),'-b');
hold on;
plot(t,inflcf(168-plot_extra:end),'--r');
title('GDP Deflator')
ylabel('Y/Y % Chg','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([0 3.0]);set(gca,'YTick',[0.0:0.5:3.0],'FontSize',6);
xlim([t(1) t(end)]);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;

subplot(3,2,5);
plot(t,Y(168-plot_extra:end,4)/100,'-b');
hold on;
plot(t,path(168-plot_extra:end,4)/100,'--r');
title('Divisia M4')
ylabel('Log-scale','FontSize',8);
set(gca,'XTick',t(1:4:end),'FontSize',6);
set(gca,'XTickLabel',{'','2007','','2009','','2011','','2013','','2015'},'FontSize',6);
ylim([6.9 7.3]);set(gca,'YTick',[6.9:0.1:7.3],'FontSize',6);
xlim([t(1) t(end)]);
box on; grid on;
set(gca, 'Layer', 'top');
hold off;