%% THIS SCRIPT PLOTS THE LIQUDITY EFFECT OF AN UNWEIGHTED MONETARY AGGREGATE 
%% FOR DIFFERENT VALUES OF THE CES SUB-UTILITY FUNCTION FOR KKSV
clear
clc

%% SETUP DYNARE

omega	= 0.5;
nu		= 0.2;
save parameterfile omega nu
dynare kksvMPLiquidityEffect nolog noclearall

clear
clc
close all

omegas 	= 0.0:0.1:10;		%0.1
nus		= 0.0:0.05:1.0;		%0.05

nm_u_storage = zeros(length(omegas),length(nus));
nm_storage 	 = zeros(length(omegas),length(nus));

count = 0;

for oo = 1:1:length(omegas);
	for nn = 1:1:length(nus);
		omega	= omegas(oo);
		nu		= nus(nn);
		save parameterfile omega nu
		kksvMPLiquidityEffect
		nm_u_storage(oo,nn) = 100*nm_u_emp(1,1);
		nm_storage(oo,nn)  = 100*nm_emp(1,1);
		count = count + 1;
		workbar(count/(length(omegas)*length(nus)),'Calculating IRFs...','Progress');
	end;
end;

figure(1);
mesh(nus,omegas,nm_u_storage);
hold on;
%surf(nus,omegas,zeros(length(omegas),length(nus)));
set(gca,'XTick',0.0:0.2:1.0);
set(gca,'YTick',0.0:1.0:10.0);
xlabel('\nu','FontSize',14);
ylabel('\omega','FontSize',14);
zlabel(sprintf('Liquidity Effect \nUnweighted Monetary Aggregate'),'FontSize',14);
set(gca,'ZTick',-3.0:1.0:10.0);
xlim([0.0 1.0]);
ylim([0.0 10.0]);
zlim([-3.0 10.0]);
view([-50 10])
box on; grid on;
set(gca, 'Layer', 'top');

%% Make Black and White for Journal Printing
colormap([0 0 0]);
shading interp;

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'portrait');
set(gcf, 'PaperPosition', [-0.2 -0.5 9.5 9.0]);
set(gcf, 'PaperSize', [8.9 7.9]);
print(['MSS16-420Fig9.pdf'],'-dpdf')