% THIS FUNCTION COMPUTES VARIANCE DECOMPOSITIONS FROM A SVAR WHERE

function [var_decomp] = get_var_decomp(Bcomp, VC_eps, var_decomp_horizons);
%--------------------------------------------------------------------------
%
% DESCRIPTION:
%
% This routine computes forecast error variance decompostions
%
%--------------------------------------------------------------------------
%
% INPUTS:
%
% Bcomp:   matrix with structure of estimated reduced-form coefficients in 
%           companion form excluding all the deterministic terms. 
%           This includes the estimated parameters in the partition 
%           n x (n x (n x vlag)). The remaining partition is made up of a 
%           diagonalic identity matrix that pins down the lead-lag relation 
%           between variables. The size is (n x vlag) x (n x vlag).  
%
% VC_eps:  covariance matrix of reduced-form residuals, size n x n
%
% 
% var_decomp_horizons: is a column vector defining which forecasts to 
%			compute var decomps for (i.e. var_decomp_horizons = [1; 12; 24; 60])
%--------------------------------------------------------------------------
%
% OUTPUT:
%
% var_decomp: forecast error variance decompositions 
%			  length(var_decomp_horizons) x nvars x nvars
%--------------------------------------------------------------------------
%
% Author:  Lee Smith October, 2016
%
%--------------------------------------------------------------------------
%%
Nbig = length(VC_eps);
Nbigcomp = length(Bcomp);

%%
%% 1.) COMPUTE THE CHOLESKY DECOMPOSITION OF THE REDUCED FORM COVARIANCE MATRIX AND COMPANION FORM
%%
VC_epschol = chol(VC_eps)';
VC_epschol_comp = [VC_epschol; zeros(Nbigcomp-Nbig,Nbig)];

%%
%% 2.) COMPUTE THE FORECAST ERRORS FOR THE DESIRED LENGTH
%%
max_forecast 			= max(var_decomp_horizons);
forecast_error_var_j 	= zeros(Nbigcomp,Nbigcomp,Nbig,max_forecast);

for jj = 1:1:Nbig;
	forecast_error_var_j(:,:,jj,1) = VC_epschol_comp(:,jj)*VC_epschol_comp(:,jj)';
end;

for ff = 2:1:max_forecast;
	for jj = 1:1:Nbig;
		forecast_error_var_j(:,:,jj,ff) = Bcomp*forecast_error_var_j(:,:,jj,ff-1)*Bcomp' + forecast_error_var_j(:,:,jj,1);
	end;
end;

%%
%% 3.) COMPUTE THE VARIANCE DECOMPOSITIONS OF THE FORECAST ERROR
%%

lvd = length(var_decomp_horizons);
var_decomp = zeros(lvd,Nbig,Nbig);

for ff = 1:1:lvd;
	forecast = var_decomp_horizons(ff,1);
	for ii = 1:1:Nbig;
		for jj = 1:1:Nbig;
			var_decomp(ff,jj,ii) = forecast_error_var_j(ii,ii,jj,forecast)/sum(forecast_error_var_j(ii,ii,:,forecast));%(FE_for_variable(1,jj)^2)/FEV_for_variable;
		end; 	
	end;		
end;			